@@ -14,10 +14,9 @@ from .engine import Engine
 from .feeds import RSSFeedEngine
 from .links import Link
 from .page import Page
-
-
 def get_subcollections(collection):
-    subcollection_set = set()
+
+    subcollection_set = set() # creates a set to add new subcollections to
 
     for page in collection._pages:
 
@@ -34,6 +33,7 @@ def get_subcollections(collection):
     return subcollection_set
 
 
+
 class Site:
     """
     The site stores your pages and collections to be rendered.
@@ -74,10 +74,10 @@ class Site:
     SITE_TITLE: str = "Untitled Site"
     SITE_LINK: str = "https://example.com"
     SITE_URL: str = "https://example.com"
+    strict: bool = False
 
     def __init__(
             self,
-            strict: bool = False,
             search=None,
             search_keys=[],
             timezone: str='',
@@ -106,7 +106,10 @@ class Site:
         self.output_path = Path(self.output_path)
 
         # strict deletes the directory and rebuilds it from scratch
-        if strict and self.output_path.is_dir():
+        if self.output_path.exists() and not self.output_path.is_dir():
+            raise ValueError('output path cannot point to an existing file')
+
+        if self.strict and self.output_path.exists():
             shutil.rmtree(self.output_path)
 
         # copy a defined static path into output path
@@ -163,7 +166,6 @@ class Site:
         setattr(self, collection.title, collection)
 
         for page in collection._pages:
-            logging.warning(page)
             self.route(cls=page)
 
         if collection.has_archive:
@@ -214,7 +216,8 @@ class Site:
 
         for page in self.routes:
             engine = self.engines.get(page.engine, self.engines["default_engine"])
-            content = engine.render(page, content=page.content, **vars(self))
+            content = engine.render(page, content=page.markup,
+                    markup=page.markup, **vars(self))
 
             for route in page.routes:
                 logging.info(f"starting on {route=}")
